import { useSelector } from "react-redux";
import { combineEpics } from "redux-observable";
import { map, ignoreElements } from "rxjs/operators";
import { ofAction } from "@datalayer/typescript-fsa-redux-observable";
import { reducerWithInitialState } from "typescript-fsa-reducers";
export const consoleInitialState = {
    outputs: 0
};
/* Selectors */
export const selectConsole = () => useSelector((state) => {
    if (state.console) {
        return state.console;
    }
    return { outputs: 0 };
});
/* Actions */
import actionCreatorFactory from "typescript-fsa";
export var ActionType;
(function (ActionType) {
    ActionType["OUTPUTS"] = "console/OUTPUTS";
    ActionType["EXECUTE"] = "console/EXECUTE";
})(ActionType || (ActionType = {}));
const actionCreator = actionCreatorFactory('jupyterReact');
export const consoleActions = {
    outputs: actionCreator.async(ActionType.OUTPUTS),
    execute: actionCreator.async(ActionType.EXECUTE),
};
/* Epics */
export const consoleEpics = (consoleLumino) => {
    const outputsEpic = action$ => action$.pipe(ofAction(consoleActions.outputs.started), map(action => {
        return consoleActions.outputs.done({
            params: action.payload,
            result: action.payload
        });
    }));
    const executeEpic = action$ => action$.pipe(ofAction(consoleActions.execute.started), 
    //      tap(action => consoleLumino.execute()),
    ignoreElements());
    const loggingEpic = action$ => action$
        .pipe(ofAction(consoleActions.outputs.started), 
    //      tap(action => console.log(action.type)),
    ignoreElements());
    return combineEpics(loggingEpic, outputsEpic, executeEpic);
};
/* Reducers */
export const consoleReducer = reducerWithInitialState(consoleInitialState)
    .case(consoleActions.outputs.done, (state, success) => {
    return Object.assign(Object.assign({}, state), { outputs: success.result });
});
//# sourceMappingURL=ConsoleState.js.map