import { Fragment as _Fragment, jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { useMemo } from "react";
import { useDispatch, useStore } from "react-redux";
import NotebookAdapter from './NotebookAdapter';
import LuminoAttached from '../../lumino/LuminoAttached';
import { notebookEpics, notebookActions, notebookReducer, selectNotebook } from './NotebookState';
import CellSidebarDefault from './extension/CellSidebarDefault';
import { asObservable } from '../../lumino/LuminoObservable';
/**
 * The React portals created by the Notebook component.
 */
const Portals = () => {
    const notebook = selectNotebook();
    const portals = notebook.portals;
    return _jsx(_Fragment, { children: portals.map((portal) => portal) }, void 0);
};
/**
 * This components creates a Notebook as a collection of cells
 * with sidebars.
 *
 * @param props The notebook properties.
 * @returns A Notebook React.js component.
 */
const NotebookLumino = (props) => {
    const injectableStore = useStore();
    const notebookLumino = useMemo(() => new NotebookAdapter(props, injectableStore), []);
    const dispatch = useDispatch();
    notebookLumino.manager.ready.then(() => {
        notebookLumino.createApp(props.path);
        const notebookChange$ = asObservable(notebookLumino.notebookPanel.model.sharedModel.changed);
        notebookChange$.subscribe(notebookChange => {
            dispatch(notebookActions.notebookChange.started(notebookChange));
        });
        const activeCellChanged$ = asObservable(notebookLumino.notebookPanel.content.activeCellChanged);
        activeCellChanged$.subscribe(activeCellChanged => {
            dispatch(notebookActions.activeCellChange.started(activeCellChanged));
        });
        const kernelStatusChanged$ = asObservable(notebookLumino.notebookPanel.sessionContext.statusChanged);
        kernelStatusChanged$.subscribe(kernelStatusChanged => {
            dispatch(notebookActions.kernelStatusChanged.started(kernelStatusChanged));
        });
        injectableStore.injectReducer('notebook', notebookReducer);
        injectableStore.injectEpic(notebookEpics(notebookLumino));
    });
    return (_jsxs("div", Object.assign({ css: {
            '& .jp-Toolbar': {
                display: 'none',
            },
            '& .jp-Cell': {
                width: `calc(100% - ${props.sidebarMargin}px)`,
            },
            '& .jp-Cell .jp-CellHeader': {
                height: 'auto',
                position: 'absolute',
                top: '-5px',
                left: `${props.sidebarMargin + 10}px`,
            },
            '& .jp-Cell .dla-cellHeaderContainer': {
                padding: '4px 8px',
                width: `${props.sidebarMargin + 10}px`,
                cursor: 'pointer',
                userSelect: 'none',
                marginLeft: 'auto',
                zIndex: 100,
            },
        } }, { children: [_jsx(Portals, {}, void 0),
            _jsx(LuminoAttached, { children: notebookLumino.panel }, void 0)] }), void 0));
};
NotebookLumino.defaultProps = {
    ipywidgets: 'lab',
    sidebarComponent: CellSidebarDefault,
    sidebarMargin: 100,
};
export default NotebookLumino;
//# sourceMappingURL=NotebookLumino.js.map