import { useSelector } from "react-redux";
import actionCreatorFactory from "typescript-fsa";
import { combineEpics } from "redux-observable";
import { map, ignoreElements } from "rxjs/operators";
import { ofAction } from "@datalayer/typescript-fsa-redux-observable";
import { reducerWithInitialState } from "typescript-fsa-reducers";
export const outputInitialState = {
    outputs: 0
};
/* Selectors */
export const selectOutput = () => useSelector((state) => {
    if (state.Output) {
        return state.Output;
    }
    return { outputs: 0 };
});
/* Actions */
export var ActionType;
(function (ActionType) {
    ActionType["OUTPUTS"] = "Output/OUTPUTS";
    ActionType["EXECUTE"] = "Output/EXECUTE";
})(ActionType || (ActionType = {}));
const actionCreator = actionCreatorFactory('jupyterReact');
export const OutputActions = {
    outputs: actionCreator.async(ActionType.OUTPUTS),
    execute: actionCreator.async(ActionType.EXECUTE),
};
/* Epics */
export const OutputEpics = (OutputAdapter) => {
    const outputsEpic = action$ => action$.pipe(ofAction(OutputActions.outputs.started), map(action => {
        return OutputActions.outputs.done({
            params: action.payload,
            result: action.payload
        });
    }));
    const executeEpic = action$ => action$.pipe(ofAction(OutputActions.execute.started), 
    //      tap(action => OutputAdapter.execute()),
    ignoreElements());
    const loggingEpic = action$ => action$
        .pipe(ofAction(OutputActions.outputs.started), 
    //      tap(action => Output.log(action.type)),
    ignoreElements());
    return combineEpics(loggingEpic, outputsEpic, executeEpic);
};
/* Reducers */
export const OutputReducer = reducerWithInitialState(outputInitialState)
    .case(OutputActions.outputs.done, (state, success) => {
    return Object.assign(Object.assign({}, state), { outputs: success.result });
});
//# sourceMappingURL=OutputState.js.map