import { useSelector } from "react-redux";
import actionCreatorFactory from "typescript-fsa";
import { combineEpics } from "redux-observable";
import { map } from "rxjs/operators";
import { ofAction } from "@datalayer/typescript-fsa-redux-observable";
import { reducerWithInitialState } from "typescript-fsa-reducers";
export const terminalInitialState = {
    dark: false
};
/* Selectors */
export const selectTerminal = () => useSelector((state) => {
    if (state.terminal) {
        return state.terminal;
    }
    return { dark: false };
});
/* Actions */
export var ActionType;
(function (ActionType) {
    ActionType["DARK"] = "terminal/DARK";
})(ActionType || (ActionType = {}));
const actionCreator = actionCreatorFactory('jupyterReact');
export const terminalActions = {
    dark: actionCreator.async(ActionType.DARK),
};
/* Epics */
export const terminalEpics = (terminalLumino) => {
    const themeEpic = action$ => action$.pipe(ofAction(terminalActions.dark.started), map(action => {
        (action.payload) ?
            terminalLumino.setTheme('dark')
            :
                terminalLumino.setTheme('light');
        return terminalActions.dark.done({
            params: action.payload,
            result: action.payload
        });
    }));
    return combineEpics(themeEpic);
};
/* Reducers */
export const terminalReducer = reducerWithInitialState(terminalInitialState)
    .case(terminalActions.dark.done, (state, success) => {
    return Object.assign(Object.assign({}, state), { dark: success.result });
});
//# sourceMappingURL=TerminalState.js.map